@@ -22,7 +22,9 @@ use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 
 sub new {
   my ($class, $args) = @_;
-  my $self = {resourceName => $args->{resourceName}};
+  my $self = {
+    campaignBidModifier => $args->{campaignBidModifier},
+    resourceName        => $args->{resourceName}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
